@@ -2,7 +2,7 @@ from abc import ABC
 
 from telegram import ext
 
-from botty.handlers.types import PTBHandler
+from botty.types import PTBHandler
 
 from .message import MessageHandler
 
@@ -10,6 +10,5 @@ from .message import MessageHandler
 class TextHandler(MessageHandler, ABC):
     filters = MessageHandler.filters & ext.filters.TEXT
 
-    @classmethod
-    def build(cls) -> PTBHandler:
-        return ext.MessageHandler(cls.filters, cls._handle)
+    def build(self) -> PTBHandler:
+        return ext.MessageHandler(self.filters, self.handle)
